/**
 * CronOptions interface defines the structure for specifying cron fields.
 * Each field is optional and, if omitted, defaults to '*'.
 */
export interface CronOptions {
    readonly minute?: string;
    readonly hour?: string;
    readonly day?: string;
    readonly month?: string;
    readonly weekDay?: string;
}
/**
 * The Cron class provides a structure to define, validate, and manipulate cron expressions.
 * It includes pre-defined schedules and supports custom cron expressions.
 */
export declare class Cron {
    static readonly HOURLY: Cron;
    static readonly DAILY: Cron;
    static readonly WEEKLY: Cron;
    static readonly MONTHLY: Cron;
    static readonly YEARLY: Cron;
    readonly minute: string;
    readonly hour: string;
    readonly day: string;
    readonly month: string;
    readonly weekDay: string;
    /**
     * Constructs a Cron instance with each field defaulting to '*' if not specified.
     * @param options CronOptions object for defining each cron field.
     */
    constructor(options?: CronOptions);
    /**
     * Returns the cron expression as a single string in standard cron format.
     * @returns The cron expression string.
     */
    toString(): string;
    /**
     * Converts the cron expression to a JSON-compatible string.
     * @returns The cron expression in string format, suitable for JSON.
     */
    toJSON(): string;
    /**
     * Creates a Cron instance from provided cron options.
     * @param options CronOptions object for defining each cron field.
     * @returns A new Cron instance with the specified options.
     */
    static fromFields(options: CronOptions): Cron;
    /**
     * Parses a cron expression string into a Cron instance. Supports standard POSIX format and special strings like "@hourly".
     * @param expression A valid cron expression string (5 fields or predefined like "@hourly").
     * @throws Error if the expression does not have exactly 5 fields and is not a recognized special string.
     * @returns A new Cron instance.
     */
    static fromExpression(expression: string): Cron;
}
/**
 * Validates a POSIX cron expression string, checking adherence to constraints for each field.
 * @param expression A cron expression string to validate (5 fields).
 * @returns True if the cron expression is valid, otherwise false.
 */
export declare function isValidCronExpression(expression: string): boolean;
